==> rendition-13.0.0.tgz: package/dist_esm5/components/Table/TableRow.js <==
import { __assign, __extends, __makeTemplateObject } from "tslib";
import get from 'lodash/get';
import isFunction from 'lodash/isFunction';
import map from 'lodash/map';
import * as React from 'react';
import styled from 'styled-components';
import Checkbox from '../Checkbox';
var renderField = function (row, column) {
    var value = get(row, column.field);
    if (column.render) {
        return column.render(value, row);
    }
    return value == null ? '' : value;
};
export var CheckboxWrapper = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tdisplay: inline-block;\n\tvertical-align: middle;\n"], ["\n\tdisplay: inline-block;\n\tvertical-align: middle;\n"])));
var TableRow = (function (_super) {
    __extends(TableRow, _super);
    function TableRow() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TableRow.prototype.render = function () {
        var _this = this;
        var _a = this.props, attributes = _a.attributes, checkboxAttributes = _a.checkboxAttributes, columns = _a.columns, className = _a.className, data = _a.data, href = _a.href, keyAttribute = _a.keyAttribute, isChecked = _a.isChecked, isHighlighted = _a.isHighlighted, isDisabled = _a.isDisabled, showCheck = _a.showCheck;
        return (React.createElement("div", { "data-display": "table-row", "data-highlight": isChecked || isHighlighted, className: className },
            showCheck && (React.createElement(CheckboxWrapper, { "data-display": "table-cell" },
                React.createElement(Checkbox, __assign({ checked: isChecked, disabled: isDisabled, "data-key": keyAttribute, onChange: this.props.toggleChecked }, checkboxAttributes)))),
            map(columns, function (column) {
                var cellAttributes = isFunction(column.cellAttributes)
                    ? column.cellAttributes(data, get(data, column.field))
                    : column.cellAttributes || {};
                return (React.createElement("a", __assign({}, attributes, { href: href, "data-display": "table-cell", "data-key": keyAttribute, onClick: _this.props.onRowClick }, cellAttributes, { key: column.field }), renderField(data, column)));
            })));
    };
    return TableRow;
}(React.PureComponent));
export { TableRow };
var templateObject_1;

==> rendition-15.1.0.tgz: package/dist_esm5/components/Table/TableRow.js <==
import { __assign, __extends, __makeTemplateObject } from "tslib";
import get from 'lodash/get';
import map from 'lodash/map';
import * as React from 'react';
import styled from 'styled-components';
import Checkbox from '../Checkbox';
var renderField = function (row, column) {
    var value = get(row, column.field);
    if (column.render) {
        return column.render(value, row);
    }
    return value == null ? '' : value;
};
export var CheckboxWrapper = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tdisplay: inline-block;\n\tvertical-align: middle;\n"], ["\n\tdisplay: inline-block;\n\tvertical-align: middle;\n"])));
var TableRow = (function (_super) {
    __extends(TableRow, _super);
    function TableRow() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TableRow.prototype.render = function () {
        var _this = this;
        var _a = this.props, attributes = _a.attributes, checkboxAttributes = _a.checkboxAttributes, columns = _a.columns, className = _a.className, data = _a.data, href = _a.href, keyAttribute = _a.keyAttribute, isChecked = _a.isChecked, isHighlighted = _a.isHighlighted, isDisabled = _a.isDisabled, showCheck = _a.showCheck;
        return (React.createElement("div", { "data-display": "table-row", "data-highlight": isChecked || isHighlighted, className: className },
            showCheck && (React.createElement(CheckboxWrapper, { "data-display": "table-cell" },
                React.createElement(Checkbox, __assign({ checked: isChecked, disabled: isDisabled, "data-key": keyAttribute, onChange: this.props.toggleChecked }, checkboxAttributes)))),
            map(columns, function (column) {
                var cellAttributes = typeof column.cellAttributes === 'function'
                    ? column.cellAttributes(data, get(data, column.field))
                    : column.cellAttributes || {};
                return (React.createElement("a", __assign({}, attributes, { href: href, "data-display": "table-cell", "data-key": keyAttribute, onClick: _this.props.onRowClick }, cellAttributes, { key: column.field }), renderField(data, column)));
            })));
    };
    return TableRow;
}(React.PureComponent));
export { TableRow };
var templateObject_1;
